@@ -1,24 +1,28 @@
 # import from modules
+from .aggregation import Aggregation
+from .attention import SeqAttention, ImageAttention
 from .concatenate import Concatenate
 from .conv import Conv1d, Conv2d, Conv3d, Conv
-from .masked_conv2d import MaskedConv2d, MaskedConv2dA, MaskedConv2dB
 from .linear import Linear
 from .log import Log
-from .patching import Patching, PatchEmbedding2d
-from .positional_embedding import PositionalEmbedding
+from .masked_conv2d import MaskedConv2d, MaskedConv2dA, MaskedConv2dB
+from .noise import GaussianNoise
+from .patching import Patching, PatchEmbedding2d, PatchEmbedding3d
+from .positional_embedding import PositionalEmbedding, AbstractNonTrainablePositionalEmbedding, \
+    SinCosPositionalEmbedding
 from .reshape import Reshape
 from .stack import Stack
 from .vector_quantizer import VectorQuantizer
-from .attention import SeqAttention, ImageAttention
 
 __all__ = [
-    "SeqAttention",
-    "ImageAttention",
+    "Aggregation",
     "Concatenate",
     "Conv1d",
     "Conv2d",
     "Conv3d",
     "Conv",
+    "GaussianNoise",
+    "ImageAttention",
     "MaskedConv2d",
     "MaskedConv2dA",
     "MaskedConv2dB",
@@ -26,8 +30,12 @@ __all__ = [
     "Log",
     "Patching",
     "PatchEmbedding2d",
+    "PatchEmbedding3d",
     "PositionalEmbedding",
+    "AbstractNonTrainablePositionalEmbedding",
+    "SinCosPositionalEmbedding",
     "Reshape",
     "Stack",
+    "SeqAttention",
     "VectorQuantizer",
 ]
